@@ -372,7 +372,7 @@ births.net <- function(dat, at) {
     }
 
     ## Handles infTime when incoming nodes are infected
-    newNodesInf <- intersect(newNodes, which(dat$attr$status == "s"))
+    newNodesInf <- intersect(newNodes, which(dat$attr$status == "i"))
     dat$attr$infTime[newNodesInf] <- at
 
     if (length(unique(sapply(dat$attr, length))) != 1) {
