@@ -4,14 +4,10 @@ context("ICM extended models")
 
 test_that("SI, 1G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SI",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE,
+                         verbose.int = 1)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -33,14 +29,10 @@ test_that("SI, 1G, CL: 1 sim", {
 
 test_that("SI, 1G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SI",
-                         nsteps = 100,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 2, verbose = TRUE,
+                         verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -54,6 +46,7 @@ test_that("SI, 1G, CL: 2 sim", {
   plot(x)
   plot(x, y = "i.num")
   plot(x, y = "si.flow", mean.smooth = TRUE)
+  plot(x, qnts.smooth = FALSE, sim.lines = TRUE, mean.smooth = FALSE)
   expect_error(plot(x, y = "sr.flow"))
   comp_plot(x, at = 100)
   expect_error(comp_plot(x, at = 200))
@@ -62,15 +55,9 @@ test_that("SI, 1G, CL: 2 sim", {
 
 test_that("SI, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0,
-                     act.rate = 0.25)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   status.rand = FALSE)
-  control <- control.icm(type = "SI",
-                         nsteps = 25,
-                         nsims = 10,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0, act.rate = 0.25)
+  init <- init.icm(s.num = 500, i.num = 1, status.rand = FALSE)
+  control <- control.icm(type = "SI", nsteps = 25, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -92,18 +79,10 @@ test_that("SI, 1G, CL: inf.prob = 0, status.rand = FALSE", {
 
 test_that("SI, 2G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.5,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
+  param <- param.icm(inf.prob = 0.5, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1")
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SI",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -124,18 +103,10 @@ test_that("SI, 2G, CL: 1 sim", {
 
 test_that("SI, 2G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
                      balance = "g1")
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SI",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_true(all(x$epi$num == 501))
@@ -157,16 +128,10 @@ test_that("SI, 2G, CL: 2 sim", {
 
 test_that("SI, 1G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
-  control <- control.icm(type = "SI",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -187,17 +152,10 @@ test_that("SI, 1G, OP: 1 sim", {
 
 test_that("SI, 1G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SI",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -218,24 +176,12 @@ test_that("SI, 1G, OP: 2 sim", {
 
 test_that("SI, 2G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SI",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", b.rate = 1/100, b.rate.g2 = NA,
+                     ds.rate = 1/100, ds.rate.g2 = 1/100,
+                     di.rate = 1/90, di.rate.g2 = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SI", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -256,24 +202,13 @@ test_that("SI, 2G, OP: 1 sim", {
 
 test_that("SI, 2G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SI",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", b.rate = 1/100, b.rate.g2 = NA,
+                     ds.rate = 1/100, ds.rate.g2 = 1/100,
+                     di.rate = 1/90, di.rate.g2 = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SI", nsteps = 50, nsims = 2, verbose = TRUE,
+                         verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -297,16 +232,10 @@ test_that("SI, 2G, OP: 2 sim", {
 
 test_that("SIR, 1G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     rec.rate = 1/50)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   r.num = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE,
+                         verbose.int = 1)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -327,16 +256,9 @@ test_that("SIR, 1G, CL: 1 sim", {
 
 test_that("SIR, 1G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     rec.rate = 1/50)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   r.num = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -357,17 +279,9 @@ test_that("SIR, 1G, CL: 2 sim", {
 
 test_that("SIR, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0,
-                     act.rate = 0.25,
-                     rec.rate = 0)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   r.num = 0,
-                   status.rand = FALSE)
-  control <- control.icm(type = "SIR",
-                         nsteps = 10,
-                         nsims = 10,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0, status.rand = FALSE)
+  control <- control.icm(type = "SIR", nsteps = 10, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_equal(max(x$epi$i.num), 1)
@@ -390,18 +304,11 @@ test_that("SIR, 1G, CL: inf.prob = 0, status.rand = FALSE", {
 
 test_that("SIR, 2G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     rec.rate = 1/100,
-                     rec.rate.g2 = 1/100)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR",
-                         nsims = 1,
-                         nsteps = 100,
-                         verbose = FALSE)
+  control <- control.icm(type = "SIR", nsims = 1, nsteps = 100, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -422,18 +329,11 @@ test_that("SIR, 2G, CL: 1 sim", {
 
 test_that("SIR, 2G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     rec.rate = 1/100,
-                     rec.rate.g2 = 1/100)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR",
-                         nsims = 2,
-                         nsteps = 50,
-                         verbose = FALSE)
+  control <- control.icm(type = "SIR", nsims = 2, nsteps = 50, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -453,20 +353,11 @@ test_that("SIR, 2G, CL: 2 sim", {
 
 test_that("SIR, 1G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 3,
-                     rec.rate = 1/50,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90,
+  param <- param.icm(inf.prob = 0.2, act.rate = 3, rec.rate = 1/50,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   r.num = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -487,20 +378,11 @@ test_that("SIR, 1G, OP: 1 sim", {
 
 test_that("SIR, 1G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 3,
-                     rec.rate = 1/50,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90,
+  param <- param.icm(inf.prob = 0.2, act.rate = 3, rec.rate = 1/50,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90,
                      dr.rate = 1/100)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   r.num = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -521,26 +403,15 @@ test_that("SIR, 1G, OP: 2 sim", {
 
 test_that("SIR, 2G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     inf.prob.g2 = 0.1,
-                     act.rate = 3,
-                     balance = "g1",
-                     rec.rate = 1/50,
-                     rec.rate.g2 = 1/50,
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90,
-                     dr.rate = 1/100,
-                     dr.rate.g2 = 1/100)
+  param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 3,
+                     balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
+                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90,
+                     dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  control <- control.icm(type = "SIR", nsteps = 100, nsims = 1, verbose = TRUE,
+                         verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -561,26 +432,15 @@ test_that("SIR, 2G, OP: 1 sim", {
 
 test_that("SIR, 2G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     inf.prob.g2 = 0.1,
-                     act.rate = 3,
-                     balance = "g1",
-                     rec.rate = 1/50,
-                     rec.rate.g2 = 1/50,
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90,
-                     dr.rate = 1/100,
-                     dr.rate.g2 = 1/100)
+  param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 3,
+                     balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
+                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90,
+                     dr.rate = 1/100, dr.rate.g2 = 1/100)
   init <- init.icm(s.num = 500, i.num = 1, r.num = 0,
                    s.num.g2 = 500, i.num.g2 = 0, r.num.g2 = 0)
-  control <- control.icm(type = "SIR",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  control <- control.icm(type = "SIR", nsteps = 50, nsims = 2, verbose = TRUE,
+                         verbose.int = 1)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -603,17 +463,12 @@ test_that("SIR, 2G, OP: 2 sim", {
 
 test_that("SIS, 1G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     rec.rate = 1/50)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE,
+                         verbose.int = 1)
   x <- icm(param, init, control)
-  expect_equal(max(x$epi$s.num+x$epi$i.num), 501)
+  expect_equal(max(x$epi$s.num + x$epi$i.num), 501)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
@@ -633,17 +488,11 @@ test_that("SIS, 1G, CL: 1 sim", {
 
 test_that("SIS, 1G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     rec.rate = 1/50)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
-  expect_equal(max(x$epi$s.num+x$epi$i.num), 501)
+  expect_equal(max(x$epi$s.num + x$epi$i.num), 501)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
   expect_is(as.data.frame(x, out = "vals"), "data.frame")
@@ -663,16 +512,9 @@ test_that("SIS, 1G, CL: 2 sim", {
 
 test_that("SIS, 1G, CL: inf.prob = 0, status.rand = FALSE", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0,
-                     act.rate = 0.25,
-                     rec.rate = 0)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   status.rand = FALSE)
-  control <- control.icm(type = "SIS",
-                         nsteps = 10,
-                         nsims = 10,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0, act.rate = 0.25, rec.rate = 0)
+  init <- init.icm(s.num = 500, i.num = 1, status.rand = FALSE)
+  control <- control.icm(type = "SIS", nsteps = 10, nsims = 10, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -693,20 +535,10 @@ test_that("SIS, 1G, CL: inf.prob = 0, status.rand = FALSE", {
 
 test_that("SIS, 2G, CL: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     rec.rate = 1/100,
-                     rec.rate.g2 = 1/100)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SIS",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -726,20 +558,10 @@ test_that("SIS, 2G, CL: 1 sim", {
 
 test_that("SIS, 2G, CL: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.25,
-                     inf.prob.g2 = 0.1,
-                     balance = "g1",
-                     rec.rate = 1/100,
-                     rec.rate.g2 = 1/100)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 0)
-  control <- control.icm(type = "SIS",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, inf.prob.g2 = 0.1,
+                     balance = "g1", rec.rate = 1/100, rec.rate.g2 = 1/100)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 0)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -759,18 +581,10 @@ test_that("SIS, 2G, CL: 2 sim", {
 
 test_that("SIS, 1G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.5,
-                     rec.rate = 1/50,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -791,18 +605,10 @@ test_that("SIS, 1G, OP: 1 sim", {
 
 test_that("SIS, 1G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     act.rate = 0.5,
-                     rec.rate = 1/50,
-                     b.rate = 1/100,
-                     ds.rate = 1/100,
-                     di.rate = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.5, rec.rate = 1/50,
+                     b.rate = 1/100, ds.rate = 1/100, di.rate = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -823,26 +629,12 @@ test_that("SIS, 1G, OP: 2 sim", {
 
 test_that("SIS, 2G, OP: 1 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     inf.prob.g2 = 0.1,
-                     act.rate = 0.5,
-                     balance = "g1",
-                     rec.rate = 1/50,
-                     rec.rate.g2 = 1/50,
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 100,
-                         nsims = 1,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
+                     balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
+                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
+  control <- control.icm(type = "SIS", nsteps = 100, nsims = 1, verbose = TRUE)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
@@ -862,26 +654,13 @@ test_that("SIS, 2G, OP: 1 sim", {
 
 test_that("SIS, 2G, OP: 2 sim", {
   skip_on_cran()
-  param <- param.icm(inf.prob = 0.2,
-                     inf.prob.g2 = 0.1,
-                     act.rate = 0.5,
-                     balance = "g1",
-                     rec.rate = 1/50,
-                     rec.rate.g2 = 1/50,
-                     b.rate = 1/100,
-                     b.rate.g2 = NA,
-                     ds.rate = 1/100,
-                     ds.rate.g2 = 1/100,
-                     di.rate = 1/90,
-                     di.rate.g2 = 1/90)
-  init <- init.icm(s.num = 500,
-                   i.num = 1,
-                   s.num.g2 = 500,
-                   i.num.g2 = 1)
-  control <- control.icm(type = "SIS",
-                         nsteps = 50,
-                         nsims = 2,
-                         verbose = FALSE)
+  param <- param.icm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
+                     balance = "g1", rec.rate = 1/50, rec.rate.g2 = 1/50,
+                     b.rate = 1/100, b.rate.g2 = NA, ds.rate = 1/100,
+                     ds.rate.g2 = 1/100, di.rate = 1/90, di.rate.g2 = 1/90)
+  init <- init.icm(s.num = 500, i.num = 1, s.num.g2 = 500, i.num.g2 = 1)
+  control <- control.icm(type = "SIS", nsteps = 50, nsims = 2, verbose = TRUE,
+                         verbose.int = 5)
   x <- icm(param, init, control)
   expect_is(x, "icm")
   expect_is(as.data.frame(x), "data.frame")
