@@ -6,18 +6,15 @@ test_that("edges models", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, directed = FALSE)
-  est <- netest(nw,
-                formation = ~ edges,
-                dissolution = ~offset(edges),
-                target.stats = 25,
+  est <- netest(nw, formation = ~edges, target.stats = 25,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
-                verbose = FALSE)
+                verbose = TRUE)
   expect_is(est, "netest")
 
   ## "SI, 1M, CL: 1 sim"
   param <- param.net(inf.prob = 0.5)
   init <- init.net(i.num = 1)
-  control <- control.net(type = "SI", nsims = 1, nsteps = 25, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 25, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -28,14 +25,14 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
   ## "SI, 1M, CL: 1 sim, inf.prob = 0"
   param <- param.net(inf.prob = 0)
   init <- init.net(i.num = 1, status.rand = FALSE)
-  control <- control.net(type = "SI", nsims = 1, nsteps = 25, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 25, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -46,14 +43,15 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
   ## "SI, 1M, CL: 2 sim"
   param <- param.net(inf.prob = 0.5)
   init <- init.net(i.num = 1)
-  control <- control.net(type = "SI", nsims = 2, nsteps = 25, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 2, nsteps = 25, verbose = TRUE,
+                         nwstats.formula = ~edges + meandeg + concurrent)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -63,8 +61,12 @@ test_that("edges models", {
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
+  plot(x, type = "formation", plots.joined = FALSE)
+  plot(x, type = "formation", stats = "edges")
+  plot(x, type = "formation", stats = c("edges", "meandeg"))
+  plot(x, type = "formation", sim.lines = TRUE, qnts.smooth = FALSE)
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -72,7 +74,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 1)
   init <- init.net(i.num = 1, status.rand = FALSE)
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = TRUE)
+                         verbose = TRUE, tea.status = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -86,7 +88,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -95,7 +97,7 @@ test_that("edges models", {
   init <- init.net(status.vector = c(rep("i", 10),
                                      rep("s", 90)))
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -114,7 +116,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsims = 1, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -125,7 +127,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -133,7 +135,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0, rec.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 0, status.rand = FALSE)
   control <- control.net(type = "SIR", nsims = 1,
-                         nsteps = 25, verbose = FALSE)
+                         nsteps = 25, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -144,7 +146,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -152,7 +154,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.1)
   init <- init.net(i.num = 1, r.num = 0)
   control <- control.net(type = "SIR", nsims = 2, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -163,7 +165,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -171,7 +173,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.1)
   init <- init.net(status.vector = rep(c("s", "i"), each = 50))
   control <- control.net(type = "SIR", nsims = 2, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -183,7 +185,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -191,7 +193,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.9, rec.rate = 0.01)
   init <- init.net(i.num = 1)
   control <- control.net(type = "SIS", nsims = 1, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -202,7 +204,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -210,7 +212,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0, rec.rate = 0.01)
   init <- init.net(i.num = 1, status.rand = FALSE)
   control <- control.net(type = "SIS", nsims = 1, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -221,7 +223,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -229,7 +231,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.01)
   init <- init.net(i.num = 1)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -246,7 +248,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 1, rec.rate = 0.01)
   init <- init.net(i.num = 1, status.rand = FALSE)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         tea.status = TRUE, verbose = FALSE)
+                         tea.status = TRUE, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -259,7 +261,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", sim = "mean", col.status = TRUE)
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
   rm(x)
 
@@ -267,7 +269,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.01)
   init <- init.net(status.vector = c(rep("i", 10), rep("s", 90)))
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -279,7 +281,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  expect_error(plot(x, type = "network", sim = "mean", col.status = TRUE))
+  expect_error(plot(x, type = "network", sims = "mean", col.status = TRUE))
   test_net(x)
 })
 
@@ -290,22 +292,16 @@ test_that("High death rate models", {
 
   ## "netsim: 1M, ds.rate = 0.5"
   nw <- network.initialize(n = 25, directed = FALSE)
-  est <- netest(nw,
-    formation = ~ edges,
-    dissolution = ~offset(edges),
-    target.stats = 12,
-    coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
-    edapprox = TRUE,
-    verbose = FALSE)
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.01,
-                     ds.rate = 0.5,
+  est <- netest(nw, formation = ~edges, target.stats = 12,
+                coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
+                edapprox = TRUE, verbose = TRUE)
+  param <- param.net(inf.prob = 0.5, act.rate = 2,
+                     b.rate = 0.01, ds.rate = 0.5,
                      di.rate = 0.25)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 25,
                          nsims = 1, tea.status = FALSE,
-                         verbose = FALSE)
+                         verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_equal(unique(sapply(x$epi, nrow)), 25)
   expect_output(summary(x, at = 25), "EpiModel Summary")
@@ -316,15 +312,11 @@ test_that("High death rate models", {
   rm(x)
 
   ## "netsim: 1M, di.rate = 0.5"
-  param <- param.net(inf.prob = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.01,
-                     ds.rate = 0.01,
-                     di.rate = 0.5)
+  param <- param.net(inf.prob = 0.1, act.rate = 2, b.rate = 0.01,
+                     ds.rate = 0.01, di.rate = 0.5)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 25,
-                         nsims = 1, tea.status = FALSE,
-                         verbose = FALSE)
+                         nsims = 1, tea.status = FALSE, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_equal(unique(sapply(x$epi, nrow)), 25)
   expect_output(summary(x, at = 25), "EpiModel Summary")
@@ -343,23 +335,16 @@ test_that("edges bipartite models", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, bipartite = 50, directed = FALSE)
-  est5 <- netest(
-    nw,
-    formation = ~ edges,
-    dissolution = ~offset(edges),
-    target.stats = 25,
-    coef.diss = dissolution_coefs(~offset(edges), 10, 0),
-    edapprox = TRUE,
-    verbose = FALSE)
+  est5 <- netest(nw, formation = ~edges, target.stats = 25,
+                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
+                 edapprox = TRUE, verbose = TRUE)
   expect_is(est5, "netest")
 
   ## "SI, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1)
-  init <- init.net(i.num = 10, i.num.m2 = 0,
-                   status.rand = FALSE)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1)
+  init <- init.net(i.num = 10, i.num.m2 = 0, status.rand = FALSE)
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -368,19 +353,20 @@ test_that("edges bipartite models", {
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
+  plot(x, type = "network")
+  plot(x, type = "network", shp.bip = "triangle")
+  expect_error(plot(x, type = "network", shp.bip = TRUE))
   test_net(x)
   rm(x)
 
   ## "SIR, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     rec.rate = 0.1,
-                     rec.rate.m2 = 0.1)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1,
+                     rec.rate = 0.1, rec.rate.m2 = 0.1)
   init <- init.net(i.num = 10, i.num.m2 = 10,
                    r.num = 0, r.num.m2 = 0,
                    status.rand = FALSE)
   control <- control.net(type = "SIR", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -393,18 +379,12 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIR, 2M, CL: rec.rate = 0"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.25,
-                     rec.rate = 0,
-                     rec.rate.m2 = 0,
-                     act.rate = 2)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
+                     rec.rate = 0, rec.rate.m2 = 0, act.rate = 2)
   init <- init.net(i.num = 10, i.num.m2 = 10,
                    r.num = 0, r.num.m2 = 0)
-  control <- control.net(type = "SIR",
-                         nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5, param, init, control)
   expect_equal(max(x$epi$ir.flow), 0)
   expect_equal(max(x$epi$ir.flow.m2), 0)
@@ -416,14 +396,12 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIS, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.25,
-                     rec.rate = 0.01,
-                     rec.rate.m2 = 0.01)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
+                     rec.rate = 0.01, rec.rate.m2 = 0.01)
   init <- init.net(i.num = 10, i.num.m2 = 10,
                    status.rand = FALSE)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         tea.status = FALSE, verbose = FALSE)
+                         tea.status = FALSE, verbose = TRUE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -436,17 +414,11 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIS, 2M, CL: rec.rate = 0"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.25,
-                     rec.rate = 0,
-                     rec.rate.m2 = 0,
-                     act.rate = 2)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
+                     rec.rate = 0, rec.rate.m2 = 0, act.rate = 2)
   init <- init.net(i.num = 10, i.num.m2 = 10)
-  control <- control.net(type = "SIS",
-                         nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIS", nsteps = 10, nsims = 2,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5, param, init, control)
   expect_equal(max(x$epi$is.flow), 0)
   expect_equal(max(x$epi$is.flow.m2), 0)
@@ -465,24 +437,16 @@ test_that("Open population 1 mode models", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, directed = FALSE)
-  est.vit <- netest(nw,
-    formation = ~edges,
-    dissolution = ~offset(edges),
-    target.stats = 25,
-    coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
-    verbose = FALSE)
+  est.vit <- netest(nw, formation = ~edges, target.stats = 25,
+                    coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+                    verbose = TRUE)
 
   ## "SI, 1M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, b.rate = 0.02,
+                     ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SI", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -495,16 +459,11 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SI, 1M, OP, deterministic births and deaths: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, b.rate = 0.02,
+                     ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 25,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE,
+  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE,
                          b.rand = FALSE, d.rand = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
@@ -515,15 +474,12 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SI, 1M, OP: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, b.rate = 0.02,
+                     ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 10,
                          nsims = 2,
-                         verbose = FALSE,
+                         verbose = TRUE,
                          tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
@@ -537,18 +493,12 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SIR, 1M OP: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     rec.rate = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
+  param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
                      dr.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 0)
-  control <- control.net(type = "SIR", nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -561,18 +511,12 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SIR, 1M OP, deterministic births, recoveries and deaths: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     rec.rate = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
+  param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
                      dr.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 0)
-  control <- control.net(type = "SIR", nsteps = 25,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE,
+  control <- control.net(type = "SIR", nsteps = 25, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE,
                          b.rand = FALSE, d.rand = FALSE, rec.rand = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
@@ -583,18 +527,12 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SIR, 1M, OP: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     rec.rate = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
+  param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
                      dr.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 0)
-  control <- control.net(type = "SIR", nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -607,18 +545,11 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SIS, 1M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     rec.rate = 0.01,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, rec.rate = 0.01, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SIS",
-                         nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIS", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -631,11 +562,8 @@ test_that("Open population 1 mode models", {
   rm(x)
 
   ## "SIS, 1M, OP: 2 sim"
-  control <- control.net(type = "SIS",
-                         nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIS", nsteps = 10, nsims = 2,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -655,29 +583,17 @@ test_that("Open-population bipartite models", {
   skip_on_cran()
 
   nw <- network.initialize(n = 100, bipartite = 50, directed = FALSE)
-  est5.vit <- netest(nw,
-    formation = ~edges,
-    dissolution = ~offset(edges),
-    target.stats = 25,
-    coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
-    edapprox = TRUE,
-    verbose = FALSE)
+  est5.vit <- netest(nw, formation = ~edges, target.stats = 25,
+                     coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+                     edapprox = TRUE, verbose = TRUE)
 
   ## "SI, 2M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
-                     b.rate.m2 = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate.m2 = 0.02)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
+                     b.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
   init <- init.net(i.num = 10, i.num.m2 = 10)
-  control <- control.net(type = "SI", nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SI", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -690,20 +606,12 @@ test_that("Open-population bipartite models", {
   rm(x)
 
   ## "SI, 2M, OP, deterministic births and deaths: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
-                     b.rate.m2 = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate.m2 = 0.02)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
+                     b.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
   init <- init.net(i.num = 10, i.num.m2 = 10)
-  control <- control.net(type = "SI", nsteps = 25,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE,
+  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE,
                          b.rand = FALSE, d.rand = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
@@ -714,20 +622,12 @@ test_that("Open-population bipartite models", {
   rm(x)
 
   ## "SI, 2M, OP: 2 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
-                     b.rate.m2 = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate.m2 = 0.02)
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
+                     b.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
   init <- init.net(i.num = 10, i.num.m2 = 10)
-  control <- control.net(type = "SI", nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SI", nsteps = 10, nsims = 2,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -740,25 +640,15 @@ test_that("Open-population bipartite models", {
   rm(x)
 
   ## "SIR, 2M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     rec.rate = 0.1,
-                     rec.rate.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     b.rate.m2 = NA,
-                     ds.rate = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate = 0.02,
-                     di.rate.m2 = 0.02,
-                     dr.rate = 0.02,
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, rec.rate = 0.1,
+                     rec.rate.m2 = 0.1, act.rate = 2, b.rate = 0.02,
+                     b.rate.m2 = NA, ds.rate = 0.02, ds.rate.m2 = 0.02,
+                     di.rate = 0.02, di.rate.m2 = 0.02, dr.rate = 0.02,
                      dr.rate.m2 = 0.02)
   init <- init.net(i.num = 10, i.num.m2 = 0,
                    r.num = 0, r.num.m2 = 10)
-  control <- control.net(type = "SIR", nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -772,25 +662,15 @@ test_that("Open-population bipartite models", {
 
 
   ## "SIR, 2M, OP, deterministic births, deaths, and recoveries: 1 sim"
-  param <- param.net(inf.prob = 0.5,
-                     inf.prob.m2 = 0.1,
-                     rec.rate = 0.1,
-                     rec.rate.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     b.rate.m2 = NA,
-                     ds.rate = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate = 0.02,
-                     di.rate.m2 = 0.02,
-                     dr.rate = 0.02,
+  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, rec.rate = 0.1,
+                     rec.rate.m2 = 0.1, act.rate = 2, b.rate = 0.02,
+                     b.rate.m2 = NA, ds.rate = 0.02, ds.rate.m2 = 0.02,
+                     di.rate = 0.02, di.rate.m2 = 0.02, dr.rate = 0.02,
                      dr.rate.m2 = 0.02)
   init <- init.net(i.num = 10, i.num.m2 = 0,
                    r.num = 0, r.num.m2 = 10)
-  control <- control.net(type = "SIR", nsteps = 10,
-                         nsims = 1,
-                         verbose = FALSE,
-                         tea.status = FALSE,
+  control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
+                         verbose = TRUE, tea.status = FALSE,
                          b.rand = FALSE, d.rand = FALSE, rec.rand = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
@@ -802,7 +682,7 @@ test_that("Open-population bipartite models", {
 
   ## "SIR, 2M, OP: 3 sim"
   control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = TRUE, tea.status = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -822,28 +702,17 @@ test_that("Extinction open-population models", {
   skip_on_cran()
 
   nw <- network.initialize(n = 25, bipartite = 10, directed = FALSE)
-  est <- netest(nw,
-    formation = ~edges,
-    dissolution = ~offset(edges),
-    target.stats = 15,
-    coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
-    edapprox = TRUE,
-    verbose = FALSE)
+  est <- netest(nw, formation = ~edges, target.stats = 15,
+                coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+                edapprox = TRUE, verbose = TRUE)
 
   ## "netsim: 2M, ds.rate = 0.5"
-  param <- param.net(inf.prob = 0.1,
-                     inf.prob.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.5,
-                     di.rate = 0.5,
-                     b.rate.m2 = 0.02,
-                     ds.rate.m2 = 0.02,
-                     di.rate.m2 = 0.02)
+  param <- param.net(inf.prob = 0.1, inf.prob.m2 = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.5, di.rate = 0.5,
+                     b.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
   init <- init.net(i.num = 1, i.num.m2 = 0)
-  control <- control.net(type = "SI", nsteps = 30,
-                         nsims = 1, tea.status = FALSE,
-                         verbose = FALSE)
+  control <- control.net(type = "SI", nsteps = 30, nsims = 1,
+                         tea.status = FALSE, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
@@ -853,19 +722,12 @@ test_that("Extinction open-population models", {
   rm(x)
 
   ## "netsim: 2M, ds.rate.m2 = 0.5"
-  param <- param.net(inf.prob = 0.1,
-                     inf.prob.m2 = 0.1,
-                     act.rate = 2,
-                     b.rate = 0.02,
-                     ds.rate = 0.02,
-                     di.rate = 0.02,
-                     b.rate.m2 = 0.02,
-                     ds.rate.m2 = 0.5,
-                     di.rate.m2 = 0.5)
+  param <- param.net(inf.prob = 0.1, inf.prob.m2 = 0.1, act.rate = 2,
+                     b.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
+                     b.rate.m2 = 0.02, ds.rate.m2 = 0.5, di.rate.m2 = 0.5)
   init <- init.net(i.num = 1, i.num.m2 = 0)
-  control <- control.net(type = "SI", nsteps = 30,
-                         nsims = 1, tea.status = FALSE,
-                         verbose = FALSE)
+  control <- control.net(type = "SI", nsteps = 30, nsims = 1,
+                         tea.status = FALSE, verbose = TRUE)
   x <- netsim(est, param, init, control)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
