@@ -38,8 +38,8 @@ test_that("print.netest", {
   expect_output(print(est), "Model class: netest")
   expect_output(print(est), "Estimation Method: ERGM with Edges Approximation")
   expect_output(print(est), "Formation: ~edges")
-  expect_output(print(est), "Formation Targets: 50")
-  expect_output(print(est), "Edge Duration Target: 10")
+  expect_output(print(est), "Target Statistics: 50")
+  expect_output(print(est), "Target Statistics: 10")
 })
 
 test_that("print.netsim", {
@@ -64,18 +64,18 @@ test_that("print.disscoefs", {
   o <- dissolution_coefs(dissolution = ~offset(edges), duration = 25)
   expect_output(print(o), "Dissolution Coefficients")
   expect_output(print(o), "Crude Coefficient: 3.178054")
-  expect_output(print(o), "Death rate: 0")
+  expect_output(print(o), "Mortality/Exit Rate: 0")
 
   o <- dissolution_coefs(dissolution = ~offset(edges), duration = 25,
                          d.rate = 0.001)
   expect_is(o, "disscoef")
-  expect_output(print(o), "Death rate: 0.001")
+  expect_output(print(o), "Mortality/Exit Rate: 0.001")
 
   o <- dissolution_coefs(dissolution = ~offset(edges) + offset(nodematch("race")),
                          duration = c(20, 10))
   expect_output(print(o), "2.944439 -0.7472144")
-  expect_output(print(o), "Death rate: 0")
-  expect_output(print(o), "Edge Duration: 20 10")
+  expect_output(print(o), "Mortality/Exit Rate: 0")
+  expect_output(print(o), "Target Statistics: 20 10")
 
   o <- dissolution_coefs(dissolution = ~offset(edges) + offset(nodematch("race")),
                          duration = c(20, 10), d.rate = 0.001)
@@ -101,11 +101,11 @@ test_that("print.init", {
 
   i <- init.icm(s.num = 10, i.num = 10)
   expect_output(i, "ICM Initial Conditions")
-  expect_output(i, "status.rand = TRUE")
+  expect_output(i, "status.rand = FALSE")
 
   i <- init.net(s.num = 10, i.num = 10)
   expect_output(i, "Network Model Initial Conditions")
-  expect_output(i, "status.rand = TRUE")
+  expect_output(i, "status.rand = FALSE")
 })
 
 test_that("print.control", {
